define(['testsuite/qunit', 'jquery', 'ep/validate', '$i18n!en-GB', '$ready!'], function (QUnit, $, ep) {

	QUnit.module("ep/validate");

	QUnit.asyncTest("ep/validate", function() {

		QUnit.equal(
			ep.validate.email('e.vitzthum@epages.com'),
			true,
			"ep.validate.email('e.vitzthum@epages.com')"
		);

		QUnit.equal(
			ep.validate.email('e.vit@zthum@epages.com'),
			'NO_EMAIL',
			"ep.validate.email('e.vit@zthum@epages.com')"
		);

		QUnit.equal(
			ep.validate.url('http://www.epages.com/de/images'),
			true,
			"ep.validate.url('http://www.epages.com/de/images')"
		);

		QUnit.equal(
			ep.validate.url('http://vm.intern.epages.com/epages/Store.admin'),
			true,
			"ep.validate.url('http://vm.intern.epages.com/epages/Store.admin')"
		);

		QUnit.equal(
			ep.validate.url('vm.intern.epages.com/epages/Store.admin'),
			true,
			"ep.validate.url('vm.intern.epages.com/epages/Store.admin')"
		);

		QUnit.equal(
			ep.validate.url('http://vm.inter n.epages.com/epages/Store.admin'),
			'NO_URL',
			"ep.validate.url('http://vm.intern.epages.com/epages/Store.admin')"
		);

		QUnit.equal(
			ep.validate.mimetype( 'image/jpg' ),
			true,
			"ep.validate.mimetype( 'image/jpg' )"
		);

		QUnit.equal(
			ep.validate.mimetype( 'image/*' ),
			'NO_MIME',
			"ep.validate.mimetype( 'image/*' )"
		);

		QUnit.equal(
			ep.validate.mimetype( 'image/jpg', {accept:'image/*'} ),
			true,
			"ep.validate.mimetype( 'image/jpg', {accept:'image/*'} )"
		);

		QUnit.equal(
			ep.validate.mimetype( 'image/jpg', {accept:'video/*'} ),
			'MIME_NOT_ACCEPT',
			"ep.validate.mimetype( 'image/jpg', {accept:'video/*'} )"
		);

		QUnit.equal(
			ep.validate.date( '01/12/2010', {region:'en-GB'} ),
			true,
			"ep.validate.date( '01/12/2010', {region:'en-GB'} )"
		);

		QUnit.equal(
			ep.validate.date( '01.12.2010', {format:'date',region:'de-DE'} ),
			true,
			"ep.validate.date( '01.12.2010', {format:'date',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.date( '01.12.2010', {format:'date',region:'de-DE',max:1288613913629} ),
			'GREATER_THAN_MAX',
			"ep.validate.date( '01.12.2010', {format:'date',region:'de-DE',max:1288613913629} )"
		);

		QUnit.equal(
			ep.validate.date( '01/12/2010', {format:'date',region:'de-DE'} ),
			'NO_DATE',
			"ep.validate.date( '01/12/2010', {format:'date',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.date( '01/12/2010 12:00', {format:'date-time',region:'de-DE'} ),
			'NO_DATETIME',
			"ep.validate.date( '01/12/2010 12:00', {format:'date-time',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.date( '25:00', {format:'time',region:'de-DE'} ),
			'NO_TIME',
			"ep.validate.date( '25:00', {format:'time',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.date( 'Hallo Tag.', {format:'busen',region:'de-DE'} ),
			'NOT_VALID',
			"ep.validate.date( 'Hallo Tag.', {format:'busen',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.number( '12,000.99', {region:'en-GB'} ),
			true,
			"ep.validate.number( '12,000.99', {region:'en-GB'} )"
		);

		QUnit.equal(
			ep.validate.number( '12.000,99', {format:'n2',region:'de-DE'} ),
			true,
			"ep.validate.number( '12.000,99', {format:'n2',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.number( '12,000.99', {format:'n2',region:'de-DE'} ),
			'NO_NUMBER',
			"ep.validate.number( '12,000.99', {format:'n2',region:'de-DE'} )"
		);

		QUnit.equal(
			ep.validate.number( '12,000.99%', {format:'p2', region:'en-GB'} ),
			true,
			"ep.validate.number( '12,000.99%', {format:'p2', region:'en-GB'} )"
		);

		QUnit.equal(
			ep.validate.number( '12,000.99 £', {format:'c2'} ),
			'NO_CURRENCY',
			"ep.validate.number( '12,000.99 £', {format:'c2'} )"
		);

		QUnit.equal(
			ep.validate.cssColor( 'black' ),
			true,
			"ep.validate.cssColor( 'black' )"
		);

		QUnit.equal(
			ep.validate.cssColor( '#2345ff' ),
			true,
			"ep.validate.cssColor( '#2345ff' )"
		);

		QUnit.equal(
			ep.validate.cssColor( 'rgb(255,12,120)' ),
			true,
			"ep.validate.cssColor( 'rgb(255,12,120)' )"
		);

		QUnit.equal(
			ep.validate.cssColor( 'rgba(255,12,120,0.5)' ),
			true,
			"ep.validate.cssColor( 'rgba(255,12,120,0.5)' )"
		);

		QUnit.equal(
			ep.validate.cssColor( 'rgba(255,12,120,100)' ),
			'NO_COLOR_VALUE',
			"ep.validate.cssColor( 'rgba(255,12,120,100)' )"
		);

		QUnit.equal(
			ep.validate.cssColor( '#12hf34' ),
			'NO_COLOR_VALUE',
			"ep.validate.cssColor( '#12hf34' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '1.4em' ),
			true,
			"ep.validate.cssSize( '1.4em' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '12px' ),
			true,
			"ep.validate.cssSize( '12px' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '1.4px' ),
			"FLOAT_NOT_ALLOWED",
			"ep.validate.cssSize( '1.4px' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '14px', {min:10,max:16} ),
			true,
			"ep.validate.cssSize( '14px', {min:10,max:16} )"
		);

		QUnit.equal(
			ep.validate.cssSize( '18px', {min:10,max:16} ),
			'NOT_IN_RANGE',
			"ep.validate.cssSize( '18px', {min:10,max:16} )"
		);

		QUnit.equal(
			ep.validate.cssSize( '8px', {min:10} ),
			'LOWER_THAN_MIN',
			"ep.validate.cssSize( '8px', {min:10} )"
		);

		QUnit.equal(
			ep.validate.cssSize( '12' ),
			'NO_UNIT',
			"ep.validate.cssSize( '12' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '' ),
			'NO_UNIT_VALUE',
			"ep.validate.cssSize( '' )"
		);

		QUnit.equal(
			ep.validate.cssSize( 'px' ),
			'NO_CSS_NUMBER',
			"ep.validate.cssSize( 'px' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '1.4' ),
			'NO_UNIT',
			"ep.validate.cssSize( '1.4' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '4abrakadabra' ),
			'UNKNOWN_UNIT',
			"ep.validate.cssSize( '4abrakadabra' )"
		);

		QUnit.equal(
			ep.validate.cssSize( '4?' ),
			'NOT_VALID',
			"ep.validate.cssSize( '4?' )"
		);

		QUnit.equal(
			ep.validate.basic( 'Lorem ipsum', {required:true} ),
			true,
			"ep.validate.basic( 'Lorem ipsum', {required:true} )"
		);

		QUnit.equal(
			ep.validate.basic( '', {required:true} ),
			'REQUIRED',
			"ep.validate.basic( '', {required:true} )"
		);

		QUnit.equal(
			ep.validate.basic( 'Lorem ipsum', {minlength:10} ),
			true,
			"ep.validate.basic( 'Lorem ipsum', {minlength:10} )"
		);

		QUnit.equal(
			ep.validate.basic( 'Lorem ipsum', {minlength:30} ),
			'LOWER_THAN_MINLENGTH',
			"ep.validate.basic( 'Lorem ipsum', {minlength:30} )"
		);

		QUnit.equal(
			ep.validate.basic( 'Lorem ipsum', {minlength:5,maxlength:10} ),
			'NOT_IN_RANGELENGTH',
			"ep.validate.basic( 'Lorem ipsum', {minlength:5,maxlength:10} )"
		);

		QUnit.equal(
			ep.validate.creditcard( '', {required:true} ),
			'REQUIRED',
			"ep.validate.creditcard( '', {required:true} )"
		);

		QUnit.equal(
			ep.validate.creditcard( '49927398719' ),
			'NO_CREDITCARD_NUMBER',
			"ep.validate.creditcard( '49927398719' )"
		);

		QUnit.equal(
			ep.validate.creditcard( '49927398716', {required:true} ),
			true,
			"ep.validate.creditcard( '49927398716', {required:true} )"
		);

		QUnit.equal(
			ep.validate.creditcard( '4992-73-9871-6', {required:true} ),
			true,
			"ep.validate.creditcard( '4992-73-9871-6', {required:true} )"
		);

		QUnit.equal(
			ep.validate.creditcard( 'creditcardnumber', {required:true} ),
			false,
			"ep.validate.creditcard( 'creditcardnumber', {required:true} )"
		);

		QUnit.start();
	});
});